@@ -16,6 +16,7 @@ import urllib
 import gobject
 import socket
 import re
+from gconf import client_get_default
 from urllib2 import URLError
 from ziggy.languages import Languages
 from ziggy.state import AppState
@@ -86,6 +87,9 @@ class BaasGui(object):
         self.service_dialog = None
         set_application_name("Ask Ziggy")
 
+        # first handle proxy settings
+        self.handle_proxy_settings()
+        
         # Create a new programm
         program = Program.get_instance()
 
@@ -254,6 +258,13 @@ class BaasGui(object):
         lbutton.set_size_request(750, 70)
         lbutton.connect("toggled", self.menu_settings_toggled, 'direct_linkage')
         lbutton.set_active(self.state.direct_linkage)
+        
+        # service check button
+        pbutton = CheckButton(HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT)
+        pbutton.set_label('use proxy settings')
+        pbutton.set_size_request(750, 70)
+        pbutton.set_active(self.state.use_proxy)
+        pbutton.connect("toggled", self.menu_settings_toggled, 'use_proxy')
 
         # history len
         len_box = self.menu_select_history_len()
@@ -261,6 +272,7 @@ class BaasGui(object):
         box2 = VBox(False)
         box2.pack_start(len_box, False, False, 5)
         box2.pack_start(lbutton, True, True, 5)
+        box2.pack_start(pbutton, True, True, 5)
 
         self.settings_dialog.action_area.add(box2)
         self.settings_dialog.show_all()
@@ -269,6 +281,9 @@ class BaasGui(object):
         active = button.get_active()
         setattr(self.state, setting, active)
         self.state.save()
+        if setting == 'use_proxy':
+            hildon_banner_show_information(self.window, "",
+                "You must restart the application before the new setting will take effect.")
 
     def menu_select_history_len(self):
         ''' get a picker for history length '''
@@ -1001,7 +1016,7 @@ class BaasGui(object):
                 self.open_link(self.result_data[active]['url'])
             elif self.result_data[active].get('link'):
                 self.open_link(self.result_data[active]['link'])
-
+            
     def detail_open_url(self, button, entry):
         ''' opens selected search result in browser '''
         if entry.get('unescapedUrl'):
@@ -1120,6 +1135,7 @@ class BaasGui(object):
         return parea
 
     def open_link(self, link):
+        link = self.modify_result_link(link)
         osso_c = osso.Context("osso_baas_receiver", "0.0.1", False)
         osso_rpc = osso.Rpc(osso_c)
         osso_rpc.rpc_run_with_defaults("osso_browser", "open_new_window", (link,))
@@ -1131,9 +1147,17 @@ class BaasGui(object):
         elif entry.get('url'):
             link = entry['url']
         elif entry.get('link'):
-            link = entry['link']
+            link = entry['link']                           
         return link
 
+    def modify_result_link(self, link):
+        try:
+            if self.input_command == 'maemo' and link.find('showthread.php?') >= 0:
+                link += '&highlight='+urllib.quote_plus(self.input_buffer.strip().encode('latin-1'))
+        except:
+            pass
+        return link
+        
     def parse_term(self, term):
         lang = None
         if term and term.find('#')+1:
@@ -1225,4 +1249,13 @@ class BaasGui(object):
 
     def clean_maemo_title(self, title):
         title = reg_maemo.sub('',title)
-        return title.strip()
\ No newline at end of file
+        return title.strip()
+        
+    def handle_proxy_settings(self):
+        if self.state.use_proxy and client_get_default().get_bool('/system/http_proxy/use_http_proxy'):
+            port = client_get_default().get_int('/system/http_proxy/port')
+            http = client_get_default().get_string('/system/http_proxy/host')
+            proxy = "http://%s:%s/"% (http,port)
+            import os
+            os.environ['http_proxy'] = proxy
+            print "setting proxy to", proxy
\ No newline at end of file
